@@ -10,7 +10,7 @@ from the I<perldl> shell as well as the
 I<pdldoc> command-line program.
 
 Autoload files are also matched, via a search of the PDLLIB autoloader
-tree.  That behavior can be switched off with the variable 
+tree.  That behavior can be switched off with the variable
 C<$PERLDL::STRICT_DOCS> (true: don't search autoload tree; false: search
 the autoload tree.)
 
@@ -47,24 +47,20 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw( apropos aproposover usage help sig badinfo whatis );
 
 use PDL::Doc;
-use Pod::Select;
-use Pod::PlainText;
+use Pod::Text;
 use Cwd; # to help Debian packaging
 
-$PDL::onlinedoc = PDL::Doc->new(FindStdFile());
-
 # Find std file
 
 sub FindStdFile {
   my ($f) = PDL::Doc::_find_inc([qw(PDL pdldoc.db)], 0);
   warn("Unable to find PDL/pdldoc.db in ".join(":",@INC)."\n"), return if !defined $f;
   print "Found docs database $f\n" if $PDL::verbose;
-  print "Type 'help' for online help\n" if $PDL::verbose;
   return $f;
 }
 
 # used to find out how wide the screen should be
-# for printmatch() - really should check for a 
+# for printmatch() - really should check for a
 # sensible lower limit (for printmatch >~ 40
 # would be my guess)
 #
@@ -116,7 +112,7 @@ sub format_ref {
 
 
   my $width = screen_width()-17-1-$max_mod_length;
-  my $parser = Pod::PlainText->new( width => $width, indent => 0, sentence => 0 );
+  my $parser = Pod::Text->new( width => $width, indent => 0, sentence => 0 );
 
   for my $m (@match) {
     my $ref = $m->[2]{Ref} ||
@@ -128,8 +124,9 @@ sub format_ref {
     my $name = $m->[0];
     my $module = shortmod($m->[1]);
 
-    $ref = $parser->interpolate( $ref );
-    $ref = $parser->reformat( $ref );
+    $parser->output_string(\my $out_text);
+    $parser->parse_string_document("=encoding utf8\n\n=head1 $ref");
+    $ref = $out_text;
 
     # remove last new lines (so substitution doesn't append spaces at end of text)
     $ref =~ s/\n*$//;
@@ -183,7 +180,6 @@ with the C<help> function
 
 sub aproposover {
     die "Usage: aproposover \$funcname\n" if !@_;
-    die "no online doc database" unless defined $PDL::onlinedoc;
     my $func = shift;
     $func =~ s:\/:\\\/:g;
     search_docs("m/$func/",['Name','Ref','Module'],1);
@@ -191,7 +187,6 @@ sub aproposover {
 
 sub apropos  {
     die "Usage: apropos \$funcname\n" unless $#_>-1;
-    die "no online doc database" unless defined $PDL::onlinedoc;
     my $func = shift;
     printmatch aproposover $func;
 }
@@ -208,6 +203,7 @@ sub search_docs {
     my ($func,$types,$sortflag,$exact) = @_;
     my @match;
 
+    $PDL::onlinedoc //= PDL::Doc->new(FindStdFile());
     @match = $PDL::onlinedoc->search($func,$types,$sortflag);
     push(@match,find_autodoc( $func, $exact ) );
 
@@ -218,17 +214,16 @@ sub search_docs {
 
 =head2 PDL::Doc::Perldl::finddoc
 
-=for ref 
+=for ref
 
 Internal interface to the PDL documentation searcher
 
 =cut
 
-sub finddoc  {
+sub finddoc {
     local $SIG{PIPE}= sub {}; # Prevent crashing if user exits the pager
 
     die 'Usage: doc $topic' unless $#_>-1;
-    die "no online doc database" unless defined $PDL::onlinedoc;
     my $topic = shift;
 
     # See if it matches a PDL function name
@@ -241,17 +236,15 @@ sub finddoc  {
     my @match = search_docs("m/^(PDL::)?".$t2."\$/",['Name'],0) ; #matches: ^PDL::topic$ or ^topic$
 
     unless(@match) {
-      
       print "No PDL docs for '$topic'. Using 'whatis'. (Try 'apropos $topic'?)\n\n";
       whatis($topic);
       return;
-
     }
 
     # print out the matches
-
     open my $out, "| pod2text | $PDL::Doc::pager";
-    
+    binmode $out, ':encoding(UTF-8)';
+
     if($subfield) {
       if($subfield <= @match) {
 	@match = ($match[$subfield-1]);
@@ -261,7 +254,7 @@ sub finddoc  {
 	$subfield = undef;
       }
     }
-    
+
     my $num_pdl_pod_matches = scalar @match;
     my $pdl_pod_matchnum = 0;
 
@@ -303,22 +296,22 @@ sub finddoc  {
        } else {
           if(defined $m->[2]{CustomFile}) {
 
-             my $parser= Pod::Select->new;
+             require Pod::Text;
+             my $parser = Pod::Text->new;
              print $out "=head1 Autoload file \"".$m->[2]{CustomFile}."\"\n\n";
              $parser->parse_from_file($m->[2]{CustomFile},$out);
              print $out "\n\n=head2 Docs from\n\n".$m->[2]{CustomFile}."\n\n";
 
           } else {
 
-             print $out "=head1 Module ",$m->[2]{Module}, "\n\n";
-#	     print STDERR "calling funcdocs(" . $m->[0] . ", " . $m->[1] . ")\n";
-             $PDL::onlinedoc->funcdocs($m->[0],$m->[1],$out);
+             print $out "=encoding utf8\n\n=head1 Module ",$m->[2]{Module}, "\n\n";
+             $PDL::onlinedoc->funcdocs(@$m[0,1],$out);
 
           }
 
        }
     }
-  }
+}
 
 
 =head2 find_autodoc
@@ -340,7 +333,7 @@ sub find_autodoc {
     my $topic = shift;
     my $exact = shift;
     my $matcher;
-    # Fix up regexps and exact matches for the special case of 
+    # Fix up regexps and exact matches for the special case of
     # searching the autoload dirs...
     if($exact) {
 	$topic =~ s/\(\)$//;  # "func()" -> "func"
@@ -361,7 +354,7 @@ sub find_autodoc {
     return unless(@main::PDLLIB);
     @main::PDLLIB_EXPANDED = PDL::AutoLoader::expand_path(@main::PDLLIB)
 	unless(@main::PDLLIB_EXPANDED);
-    
+
     for my $dir(@main::PDLLIB_EXPANDED) {
 	if($exact) {
 	    my $file = $dir . "/" . "$topic";
@@ -409,7 +402,6 @@ Prints usage information for a PDL function
 
 sub usage {
     die 'Usage: usage $funcname' unless $#_>-1;
-    die "no online doc database" unless defined $PDL::onlinedoc;
     print usage_string(@_);
 }
 sub usage_string{
@@ -461,7 +453,6 @@ doesn't break -- it causes broadcasting.  See L<PDL::PP> and L<PDL::Broadcasting
 
 sub sig {
 	die "Usage: sig \$funcname\n" unless $#_>-1;
-	die "no online doc database" unless defined $PDL::onlinedoc;
 	my $func = shift;
 	my @match = search_docs("m/^(PDL::)?$func\$|\:\:$func\$/",['Name']);
 	my $count = @match;
@@ -525,7 +516,7 @@ sub whatis_r {
   my $prefix = shift;
   my $indent = shift;
   my $x = shift;
-  
+
   unless(defined $x) {
     print $prefix,"<undef>\n";
     return;
@@ -547,19 +538,19 @@ sub whatis_r {
       my $pre = sprintf("%s  %2d: "," "x$indent,$el);
       whatis_r($pre,$indent + $PDL::Doc::Perldl::array_indent, $x->[$el]);
       last if($el == $PDL::Doc::Perldl::max_arraylen);
-    } 
+    }
     printf "%s   ... \n"," " x $indent
       if($#$x > $PDL::Doc::Perldl::max_arraylen);
 
     return;
   }
-      
+
   if(ref $x eq 'HASH') {
     print "${prefix}Hash (".scalar(keys %$x)." elements)\n";
     my $key;
     for $key(sort keys %$x) {
       my $pre = " " x $indent .
-	        " $key: " . 
+	        " $key: " .
 		(" "x($PDL::Doc::Perldl::max_keylen - length($key))) ;
 
       whatis_r($pre,$indent + $PDL::Doc::Perldl::hash_indent, $x->{$key});
@@ -582,7 +573,7 @@ sub whatis_r {
     local $PDL::debug = 1;
 
     $y = ( (UNIVERSAL::isa($x,'PDL') && $x->nelem < 5 && $x->ndims < 2)
-	   ? 
+	   ?
 	   ": $x" :
 	   ": *****"
 	   );
@@ -642,7 +633,7 @@ The following commands support online help in the perldl shell:
  help vars      -- print information about all current ndarrays
 
  whatis <expr>  -- Describe the type and structure of an expression or ndarray.
- apropos 'word' -- search for keywords/function names 
+ apropos 'word' -- search for keywords/function names
  usage          -- print usage information for a given PDL function
  sig            -- print signature of PDL function
  badinfo        -- information on the support for bad values
@@ -689,8 +680,6 @@ sub badinfo {
     my $func = shift;
     die "Usage: badinfo \$funcname\n" unless defined $func;
 
-    die "no online doc database" unless defined $PDL::onlinedoc;
-
     local $SIG{PIPE}= sub {}; # Prevent crashing if user exits the pager
 
     my @match = search_docs("m/^(PDL::)?$func\$|\:\:$func\$/",['Name']);
